@@ -55,8 +55,8 @@ class NetcatsTool(Tool):
     ]
 
     @classmethod
-    def print_source(self):
-        print open(__file__).read()
+    def print_source(cls):
+        cls._print_source(__file__)
 
     def __init__(self, options, outfile=sys.stdout, *args, **kw):
         super(NetcatsTool, self).__init__(options, *args, **kw)
