@@ -40,8 +40,8 @@ class SSLInfoTool(Tool):
     ]
 
     @classmethod
-    def print_source(self):
-        print open(__file__).read()
+    def print_source(cls):
+        cls._print_source(__file__)
 
     @classmethod
     def __massage__(self, iterator):
